#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_NEXTPOW2_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_NEXTPOW2_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/nextpow2.hpp>

#endif
